==> apache-nuttx-9.1.1-incubating.tar.gz: nuttx/arch/z80/include/z180/arch.h <==
/****************************************************************************
 * arch/z80/arch.h
 *
 *   Copyright (C) 2012 Gregory Nutt. All rights reserved.
 *   Author: Gregory Nutt <gnutt@nuttx.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name NuttX nor the names of its contributors may be
 *    used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

/* This file should never be included directly but, rather, only indirectly
 * through nuttx/arch.h (via arch/arch.h)
 */

#ifndef __ARCH_Z80_INCLUDE_Z180_ARCH_H
#define __ARCH_Z80_INCLUDE_Z180_ARCH_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>

#include <stdint.h>

#include <arch/irq.h>

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

/****************************************************************************
 * Public Types
 ****************************************************************************/
/* The z180 address environment is represented in hardware as the 8-bit
 * Common Base Register (CBR).  CBR specifies the base address (on 4KB
 * boundaries) used to generate a 20-bit physical address for Common Area 1
 * accesses.  CBR is the upper 8-bits of the 20-bit address; the lower 14-bits
 * of the base address are implicitly zero (hence the 4KB boundary alignment).
 */

#ifdef CONFIG_ARCH_ADDRENV
typedef uint8_t save_addrenv_t;

/* At the task-level, the z180 address environment is represented as struct
 * z180_cbr_s which is defined in irq.h.
 */

struct z180_cbr_s;
typedef FAR struct z180_cbr_s *group_addrenv_t;
#endif

/****************************************************************************
 * Public Data
 ****************************************************************************/

/****************************************************************************
 * Public Function Prototypes
 ****************************************************************************/

#ifdef __cplusplus
#define EXTERN extern "C"
extern "C"
{
#else
#define EXTERN extern
#endif

#undef EXTERN
#ifdef __cplusplus
}
#endif

#endif /* __ARCH_Z80_INCLUDE_Z180_ARCH_H */

==> apache-nuttx-10.1.0-incubating.tar.gz: nuttx/arch/z80/include/z180/arch.h <==
/****************************************************************************
 * arch/z80/include/z180/arch.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/* This file should never be included directly but, rather, only indirectly
 * through nuttx/arch.h (via arch/arch.h)
 */

#ifndef __ARCH_Z80_INCLUDE_Z180_ARCH_H
#define __ARCH_Z80_INCLUDE_Z180_ARCH_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>

#include <stdint.h>

#include <arch/irq.h>

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

/****************************************************************************
 * Public Types
 ****************************************************************************/

/* The z180 address environment is represented in hardware as the 8-bit
 * Common Base Register (CBR).  CBR specifies the base address (on 4KB
 * boundaries) used to generate a 20-bit physical address for Common Area 1
 * accesses.  CBR is the upper 8-bits of the 20-bit address; the lower
 * 14-bits of the base address are implicitly zero (hence the 4KB boundary
 * alignment).
 */

#ifdef CONFIG_ARCH_ADDRENV
typedef uint8_t save_addrenv_t;

/* At the task-level, the z180 address environment is represented as struct
 * z180_cbr_s which is defined in irq.h.
 */

struct z180_cbr_s;
typedef FAR struct z180_cbr_s *group_addrenv_t;
#endif

/****************************************************************************
 * Public Data
 ****************************************************************************/

/****************************************************************************
 * Public Function Prototypes
 ****************************************************************************/

#ifdef __cplusplus
#define EXTERN extern "C"
extern "C"
{
#else
#define EXTERN extern
#endif

#undef EXTERN
#ifdef __cplusplus
}
#endif

#endif /* __ARCH_Z80_INCLUDE_Z180_ARCH_H */
